/* the Music Player Daemon (MPD)
 * (c)2003-2006 by Warren Dukes (warren.dukes@gmail.com)
 * This project's homepage is: http://www.musicpd.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef LS_H
#define LS_H

#include "../config.h"

#include "inputPlugin.h"

#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <time.h>

int lsPlaylists(int fd, char *utf8path);

char *getSuffix(char *utf8file);

int isValidRemoteUtf8Url(char *utf8url);

int isRemoteUrl(char *url);

int myStat(char *utf8file, struct stat *st);

int isDir(char *utf8name);

int isPlaylist(char *utf8file);

InputPlugin *hasMusicSuffix(char *utf8file, unsigned int next);

InputPlugin *isMusic(char *utf8file, time_t * mtime, unsigned int next);

int printRemoteUrlHandlers(int fd);

#endif
